@@ -1,13 +1,18 @@
 from __future__ import unicode_literals
+import copy
 import os
+import platform
 import shutil
+import signal
+import sys
 import tempfile
-import time
 import unittest
+import weakref
 
+from green.config import default_args
 from green.loader import loadTargets
-from green.runner import GreenTestRunner
 from green.output import GreenStream
+from green.runner import run
 
 try:
     from io import StringIO
@@ -15,70 +20,87 @@ except:
     from StringIO import StringIO
 
 
+class FakeCase(unittest.TestCase):
+    def runTest(self):
+        pass
 
-class TestGreenTestRunner(unittest.TestCase):
 
+class TestRun(unittest.TestCase):
 
     def setUp(self):
+        self.args = copy.deepcopy(default_args)
         self.stream = StringIO()
 
-
     def tearDown(self):
         del(self.stream)
 
-
-    def test_instantiate(self):
+    def test_catchSIGINT(self):
         """
-        GreenTestRunner can be instantiated and creates a default stream.
+        run() can catch SIGINT.
         """
-        gtr = GreenTestRunner(self.stream)
-        self.assertTrue(type(gtr.stream), GreenStream)
+        if platform.system() == 'Windows':
+            self.skipTest('This test is for posix-specific behavior.')
+        # Mock the list of TestResult instances that should be stopped,
+        # otherwise the actual TestResult that is running this test will be
+        # told to stop when we send SIGINT
+        saved__results = unittest.signals._results
+        unittest.signals._results = weakref.WeakKeyDictionary()
+        class KBICase(unittest.TestCase):
+            def runTest(self):
+                os.kill(os.getpid(), signal.SIGINT)
+        kc = KBICase()
+        run(kc, self.stream, self.args)
+        unittest.signals._results = saved__results
 
+    def test_stdout(self):
+        """
+        run() can use sys.stdout as the stream.
+        """
+        saved_stdout = sys.stdout
+        sys.stdout = self.stream
+        run(unittest.TestSuite(), sys.stdout, args=self.args)
+        sys.stdout = saved_stdout
+        self.assertIn('No Tests Found', self.stream.getvalue())
+
+    def test_GreenStream(self):
+        """
+        run() can use a GreenStream for output.
+        """
+        gs = GreenStream(self.stream)
+        run(unittest.TestSuite(), gs, args=self.args)
+        self.assertIn('No Tests Found', self.stream.getvalue())
 
     def test_HTML(self):
         """
         html=True causes html output
         """
-        class FakeCase(unittest.TestCase):
-            def runTest(self):
-                pass
-        gtr = GreenTestRunner(self.stream, html=True, subprocesses=1)
-        gtr.run(FakeCase())
+        self.args.html = True
+        run(FakeCase(), self.stream, self.args)
         self.assertIn('<', self.stream.getvalue())
 
-
     def test_verbose3(self):
         """
         verbose=3 causes version output, and an empty test case passes.
         """
-        class FakeCase(unittest.TestCase):
-            def runTest(self):
-                pass
-        gtr = GreenTestRunner(self.stream, verbosity=3, subprocesses=1)
-        gtr.run(FakeCase())
-        self.assertTrue('Green' in self.stream.getvalue())
-        self.assertTrue('OK' in self.stream.getvalue())
-
+        self.args.verbose = 3
+        run(FakeCase(), self.stream, self.args)
+        self.assertIn('Green', self.stream.getvalue())
+        self.assertIn('OK', self.stream.getvalue())
 
     def test_warnings(self):
         """
         setting warnings='always' doesn't crash
         """
-        class FakeCase(unittest.TestCase):
-            def runTest(self):
-                pass
-        gtr = GreenTestRunner(self.stream, warnings='always', subprocesses=1)
-        gtr.run(FakeCase())
-
+        self.args.warnings = 'always'
+        run(FakeCase(), self.stream, self.args)
+        self.assertIn('OK', self.stream.getvalue())
 
     def test_noTestsFound(self):
         """
         When we don't find any tests, we say so.
         """
-        gtr = GreenTestRunner(self.stream, subprocesses=1)
-        gtr.run(unittest.TestSuite())
-        self.assertTrue('No Tests Found' in self.stream.getvalue())
-
+        run(unittest.TestSuite(), self.stream, self.args)
+        self.assertIn('No Tests Found', self.stream.getvalue())
 
     def test_failedSaysSo(self):
         """
@@ -87,10 +109,8 @@ class TestGreenTestRunner(unittest.TestCase):
         class FailCase(unittest.TestCase):
             def runTest(self):
                 self.assertTrue(False)
-        gtr = GreenTestRunner(self.stream, subprocesses=1)
-        gtr.run(FailCase())
-        self.assertTrue('FAILED' in self.stream.getvalue())
-
+        run(FailCase(), self.stream, self.args)
+        self.assertIn('FAILED', self.stream.getvalue())
 
 
 class TestSubprocesses(unittest.TestCase):
@@ -101,7 +121,6 @@ class TestSubprocesses(unittest.TestCase):
         cls.startdir = os.getcwd()
         cls.container_dir = tempfile.mkdtemp()
 
-
     @classmethod
     def tearDownClass(cls):
         if os.getcwd() != cls.startdir:
@@ -109,12 +128,11 @@ class TestSubprocesses(unittest.TestCase):
         cls.startdir = None
         shutil.rmtree(cls.container_dir)
 
-
     def setUp(self):
         os.chdir(self.container_dir)
         self.tmpdir = tempfile.mkdtemp(dir=self.container_dir)
         self.stream = StringIO()
-
+        self.args = copy.deepcopy(default_args)
 
     def tearDown(self):
         os.chdir(self.startdir)
@@ -123,6 +141,34 @@ class TestSubprocesses(unittest.TestCase):
         shutil.rmtree(self.tmpdir)
         del(self.stream)
 
+    def test_catchSubprocessSIGINT(self):
+        """
+        run() can catch SIGINT while running a subprocess.
+        """
+        if platform.system() == 'Windows':
+            self.skipTest('This test is for posix-specific behavior.')
+        # Mock the list of TestResult instances that should be stopped,
+        # otherwise the actual TestResult that is running this test will be
+        # told to stop when we send SIGINT
+        sub_tmpdir = tempfile.mkdtemp(dir=self.tmpdir)
+        saved__results = unittest.signals._results
+        unittest.signals._results = weakref.WeakKeyDictionary()
+        fh = open(os.path.join(sub_tmpdir, 'test_sigint.py'), 'w')
+        fh.write("""
+import os
+import signal
+import unittest
+class SIGINTCase(unittest.TestCase):
+    def test00(self):
+        os.kill({}, signal.SIGINT)
+""".format(os.getpid()))
+        fh.close()
+        os.chdir(sub_tmpdir)
+        tests = loadTargets('test_sigint')
+        self.args.subprocesses = 2
+        run(tests, self.stream, self.args)
+        unittest.signals._results = saved__results
+        os.chdir(TestSubprocesses.startdir)
 
     def test_collisionProtection(self):
         """
@@ -172,10 +218,39 @@ class A(unittest.TestCase):
         # Load the tests
         os.chdir(self.tmpdir)
         tests = loadTargets('.')
-        gtr = GreenTestRunner(self.stream, subprocesses=2, termcolor=False)
-        gtr.run(tests)
+        self.args.subprocesses = 2
+        self.args.termcolor = False
+        try:
+            run(tests, self.stream, self.args)
+        except KeyboardInterrupt:
+            os.kill(os.getpid(), signal.SIGINT)
+        os.chdir(TestSubprocesses.startdir)
         self.assertIn('OK', self.stream.getvalue())
 
+    def test_detectNumSubprocesses(self):
+        """
+        args.subprocesses = 0 causes auto-detection of number of subprocesses.
+        """
+        sub_tmpdir = tempfile.mkdtemp(dir=self.tmpdir)
+        # pkg/__init__.py
+        fh = open(os.path.join(sub_tmpdir, '__init__.py'), 'w')
+        fh.write('\n')
+        fh.close()
+        # pkg/test/test_target_module.py
+        fh = open(os.path.join(sub_tmpdir, 'test_autosubprocesses.py'), 'w')
+        fh.write("""
+import unittest
+class A(unittest.TestCase):
+    def testPasses(self):
+        pass""")
+        fh.close()
+        # Load the tests
+        os.chdir(self.tmpdir)
+        tests = loadTargets('.')
+        self.args.subprocesses = 0
+        run(tests, self.stream, self.args)
+        os.chdir(TestSubprocesses.startdir)
+        self.assertIn('OK', self.stream.getvalue())
 
     def test_runCoverage(self):
         """
@@ -197,10 +272,11 @@ class A(unittest.TestCase):
         # Load the tests
         os.chdir(self.tmpdir)
         tests = loadTargets('.')
+        self.args.subprocesses = 2
+        self.args.run_coverage = True
+        run(tests, self.stream, self.args)
         os.chdir(TestSubprocesses.startdir)
-        gtr = GreenTestRunner(self.stream, subprocesses=2, run_coverage=True)
-        gtr.run(tests)
-
+        self.assertIn('OK', self.stream.getvalue())
 
     def test_badTest(self):
         """
@@ -218,15 +294,15 @@ class A(unittest.TestCase):
         # Load the tests
         os.chdir(self.tmpdir)
         tests = loadTargets('.')
+        self.args.subprocesses = 2
+        self.assertRaises(ImportError, run, tests, self.stream, self.args)
         os.chdir(TestSubprocesses.startdir)
-        gtr = GreenTestRunner(self.stream, subprocesses=2, termcolor=False)
-        self.assertRaises(ImportError, gtr.run, (tests,))
-
 
     def test_empty(self):
         """
-        GreenTestRunner.run() does not crash with empty suite and subprocesses
+        run() does not crash with empty suite and subprocesses
         """
         suite = unittest.TestSuite()
-        gtr = GreenTestRunner(self.stream, subprocesses=2, termcolor=False)
-        gtr.run(suite)
+        self.args.subprocesses = 2
+        self.args.termcolor = False
+        run(suite, self.stream, self.args)
